@@ -36,9 +36,8 @@
 #*/#########################################################################
 addPhenodata <- function(object, phenofile) {
     pdata <- read.table(phenofile, header=TRUE, sep='\t', as.is=TRUE,
-        row.names=1L)
-    pData(object) <- cbind(pData(object), pdata[sampleNames(object), ])
+        row.names=1L, stringsAsFactors=FALSE)
+    pData(object) <- cbind(pData(object), pdata[sampleNames(object), ,
+        drop=FALSE])
     object
 }
-
-# EOF
